# Changelog

## [0.1.7](https://github.com/Alesh/pyCelestia/compare/742598a52878304dabcee6b8b533df3b827e6feb...d0007fc27299058fa961c5ae03f3c9e65bb5afa5) - 2025-05-19

### Added

- Add support for share v1 and signer in blob. ([#18](https://github.com/Alesh/pyCelestia/pull/18))

### Other

- Some refactoring to improve the structure and ensure further development of the project. ([#18](https://github.com/Alesh/pyCelestia/pull/18))
- Black formatting applied ([#19](https://github.com/Alesh/pyCelestia/pull/19))